@@ -24,7 +24,7 @@ from reahl.stubble import stubclass, CallMonitor, replaced
 from reahl.tofu import scenario, expected, Fixture, uses, NoException
 from reahl.tofu.pytestsupport import with_fixtures
 
-from reahl.browsertools.browsertools import Browser
+from reahl.browsertools.browsertools import Browser, XPath
 from reahl.component.exceptions import DomainException, ProgrammerError
 from reahl.web.fw import CheckedRemoteMethod, JsonResult, MethodResult, RemoteMethod, Widget, WidgetResult
 from reahl.web.ui import Div
@@ -50,30 +50,24 @@ class RemoteMethodFixture(Fixture):
 
         return WidgetWithRemoteMethod.factory()
 
-    def new_wsgi_app(self, remote_method=None):
+    def new_wsgi_app(self, remote_method=None, enable_js=False):
         remote_method = remote_method or self.remote_method
-        return self.web_fixture.new_wsgi_app(child_factory=self.new_widget_factory(remote_method=remote_method))
+        return self.web_fixture.new_wsgi_app(child_factory=self.new_widget_factory(remote_method=remote_method), enable_js=enable_js)
 
 
-@with_fixtures(WebFixture)
-def test_remote_methods(web_fixture):
+@with_fixtures(WebFixture, RemoteMethodFixture)
+def test_remote_methods(web_fixture, remote_method_fixture):
     """A RemoteMethod is a SubResource representing a method on the server side which can be invoked via POSTing to an URL."""
 
-    fixture = web_fixture
+    fixture = remote_method_fixture
 
     def callable_object():
         return 'value returned from method'
 
     encoding = 'koi8_r'  # Deliberate
-    remote_method = RemoteMethod(web_fixture.view, 'amethod', callable_object, MethodResult(mime_type='ttext/hhtml', encoding=encoding))
+    remote_method = RemoteMethod(web_fixture.view, 'amethod', callable_object, MethodResult(mime_type='ttext/hhtml', encoding=encoding), disable_csrf_check=True)
 
-    @stubclass(Widget)
-    class WidgetWithRemoteMethod(Widget):
-        def __init__(self, view):
-            super().__init__(view)
-            view.add_resource(remote_method)
-
-    wsgi_app = fixture.new_wsgi_app(child_factory=WidgetWithRemoteMethod.factory())
+    wsgi_app = fixture.new_wsgi_app(remote_method=remote_method)
     browser = Browser(wsgi_app)
 
     # By default you cannot GET, since the method is not immutable
@@ -86,6 +80,33 @@ def test_remote_methods(web_fixture):
     assert browser.last_response.content_type == 'ttext/hhtml'
 
 
+@with_fixtures(WebFixture, RemoteMethodFixture)
+def test_remote_methods_via_ajax(web_fixture, remote_method_fixture):
+    """A RemoteMethod can be called via AJAX with CSRF protection built-in."""
+
+    fixture = remote_method_fixture
+
+    def callable_object():
+        return 'value returned from method'
+
+    remote_method = RemoteMethod(web_fixture.view, 'amethod', callable_object, MethodResult(), disable_csrf_check=False)
+
+    wsgi_app = fixture.new_wsgi_app(remote_method=remote_method, enable_js=True)
+    web_fixture.reahl_server.set_app(wsgi_app)
+    browser = web_fixture.driver_browser
+
+    # Case: using jquery to POST to the method includes the necessary xsrf info automatically
+    browser.open('/')
+    browser.execute_script('$.post("/_amethod_method", success=function(data){ $("body").attr("data-result", data) })')
+    browser.wait_for_element_present(XPath('body/@data-result'))
+    results = browser.execute_script('return $("body").attr("data-result")')
+    assert results == 'value returned from method'
+
+    # Case: POSTing without a csrf token breaks
+    browser = Browser(wsgi_app)
+    browser.post('/_amethod_method', {}, status=403)
+
+
 @with_fixtures(WebFixture, RemoteMethodFixture)
 def test_exception_handling(web_fixture, remote_method_fixture):
     """The RemoteMethod sends back the str() of an exception raised for the specified exception class."""
@@ -93,7 +114,7 @@ def test_exception_handling(web_fixture, remote_method_fixture):
 
     def fail():
         raise Exception('I failed')
-    remote_method = RemoteMethod(web_fixture.view, 'amethod', fail, MethodResult(catch_exception=Exception))
+    remote_method = RemoteMethod(web_fixture.view, 'amethod', fail, MethodResult(catch_exception=Exception), disable_csrf_check=True)
 
     wsgi_app = remote_method_fixture.new_wsgi_app(remote_method=remote_method)
     browser = Browser(wsgi_app)
@@ -108,7 +129,7 @@ def test_idempotent_remote_methods(web_fixture, remote_method_fixture):
 
     def callable_object():
         return 'value returned from method'
-    remote_method = RemoteMethod(web_fixture.view, 'amethod', callable_object, MethodResult(), idempotent=True)
+    remote_method = RemoteMethod(web_fixture.view, 'amethod', callable_object, MethodResult(), idempotent=True, disable_csrf_check=True)
 
     wsgi_app = remote_method_fixture.new_wsgi_app(remote_method=remote_method)
     browser = Browser(wsgi_app)
@@ -136,7 +157,7 @@ def test_immutable_remote_methods(web_fixture, remote_method_fixture, sql_alchem
             assert Session.query(TestObject).count() == 1
             return 'value returned from method'
         
-        remote_method = RemoteMethod(web_fixture.view, 'amethod', callable_object, MethodResult(), immutable=True)
+        remote_method = RemoteMethod(web_fixture.view, 'amethod', callable_object, MethodResult(), immutable=True, disable_csrf_check=True)
 
         assert remote_method.idempotent  # Immutable methods are idempotent
 
@@ -169,7 +190,7 @@ def test_arguments_to_remote_methods(web_fixture, remote_method_fixture, argumen
         fixture.method_kwargs = kwargs
         return ''
 
-    remote_method = RemoteMethod(web_fixture.view, 'amethod', callable_object, MethodResult(), idempotent=fixture.idempotent)
+    remote_method = RemoteMethod(web_fixture.view, 'amethod', callable_object, MethodResult(), idempotent=fixture.idempotent, disable_csrf_check=True)
 
     wsgi_app = remote_method_fixture.new_wsgi_app(remote_method=remote_method)
     browser = Browser(wsgi_app)
@@ -195,7 +216,8 @@ def test_checked_arguments(web_fixture, remote_method_fixture, argument_scenario
     remote_method = CheckedRemoteMethod(web_fixture.view, 'amethod', callable_object, MethodResult(),
                                         idempotent=fixture.idempotent,
                                         anint=IntegerField(),
-                                        astring=Field())
+                                        astring=Field(),
+                                        disable_csrf_check=True)
 
     wsgi_app = remote_method_fixture.new_wsgi_app(remote_method=remote_method)
     browser = Browser(wsgi_app)
@@ -241,8 +263,8 @@ class ResultScenarios(Fixture):
         self.web_fixture.view.page = self.method_result.result_widget
 
         self.value_to_return = 'ignored in this case'
-        self.expected_response = {'widgets': {"someid": '<the widget contents><script type="text/javascript">javascriptsome</script>'},
-                                  'success': True}
+        self.expected_response = {'result': {"someid": '<the widget contents><script type="text/javascript">javascriptsome</script>'},
+                                  'success': True, 'exception': ''}
         self.expected_charset = self.method_result.encoding
         self.expected_content_type = 'application/json'
         def results_match(expected, actual):
@@ -258,7 +280,7 @@ def test_different_kinds_of_result(web_fixture, remote_method_fixture, result_sc
 
     def callable_object():
         return fixture.value_to_return
-    remote_method = RemoteMethod(web_fixture.view, 'amethod', callable_object, default_result=fixture.method_result)
+    remote_method = RemoteMethod(web_fixture.view, 'amethod', callable_object, default_result=fixture.method_result, disable_csrf_check=True)
 
     wsgi_app = remote_method_fixture.new_wsgi_app(remote_method=remote_method)
     browser = Browser(wsgi_app)
@@ -277,7 +299,7 @@ def test_exception_handling_for_json(web_fixture, remote_method_fixture, json_re
 
     def fail():
         raise Exception('exception text')
-    remote_method = RemoteMethod(web_fixture.view, 'amethod', fail, default_result=fixture.method_result)
+    remote_method = RemoteMethod(web_fixture.view, 'amethod', fail, default_result=fixture.method_result, disable_csrf_check=True)
 
     wsgi_app = remote_method_fixture.new_wsgi_app(remote_method=remote_method)
     browser = Browser(wsgi_app)
@@ -296,7 +318,7 @@ def test_exception_handling_for_widgets(web_fixture, remote_method_fixture, widg
 
     def fail():
         raise Exception('exception text')
-    remote_method = RemoteMethod(web_fixture.view, 'amethod', fail, default_result=fixture.method_result)
+    remote_method = RemoteMethod(web_fixture.view, 'amethod', fail, default_result=fixture.method_result, disable_csrf_check=True)
 
     wsgi_app = remote_method_fixture.new_wsgi_app(remote_method=remote_method)
     browser = Browser(wsgi_app)
@@ -325,7 +347,7 @@ class RegenerateMethodResultScenarios(Fixture):
             fixture.method_called += 1
             if fixture.exception:
                 raise DomainException('ex')
-        return RemoteMethod(self.web_fixture.view, 'amethod', callable_to_call, self.method_result, immutable=False)
+        return RemoteMethod(self.web_fixture.view, 'amethod', callable_to_call, self.method_result, immutable=False, disable_csrf_check=True)
 
     @scenario
     def success(self):
@@ -404,24 +426,35 @@ class WidgetResultScenarios(Fixture):
                 def change_something():
                     fixture.changes_made = True
                     if fixture.exception:
-                        raise DomainException('ex')
+                        raise DomainException(message='breaking intentionally', handled_inline=fixture.handle_inline)
                 remote_method = RemoteMethod(view, 'amethod', change_something, default_result=method_result,
-                                             immutable=False)
+                                             immutable=False, disable_csrf_check=True)
                 view.add_resource(remote_method)
         return WidgetWithRemoteMethod
 
     @scenario
     def success(self):
         self.exception = False
+        self.handle_inline = True
         self.expected_response = {'success': True,
-                                  'widgets': {'an_id': '<changed contents><script type="text/javascript">js(changed contents)</script>'}}
+                                  'exception': '',
+                                  'result': {'an_id': '<changed contents><script type="text/javascript">js(changed contents)</script>'}}
 
     @scenario
     def exception(self):
         self.exception = True
+        self.handle_inline = False
         self.expected_response = {'success': False,
-                                  'widgets': {'an_id': '<changed contents><script type="text/javascript">js(changed contents)</script>'}}
+                                  'exception': 'breaking intentionally',
+                                  'result': {'an_id': '<changed contents><script type="text/javascript">js(changed contents)</script>'}}
 
+    @scenario
+    def exception_inline(self):
+        self.exception = True
+        self.handle_inline = True
+        self.expected_response = {'success': False,
+                                  'exception': '',
+                                  'result': {'an_id': '<changed contents><script type="text/javascript">js(changed contents)</script>'}}
 
 @with_fixtures(WebFixture, WidgetResultScenarios)
 def test_widgets_that_change_during_method_processing(web_fixture, widget_result_scenarios):
@@ -468,7 +501,7 @@ def test_coactive_widgets(web_fixture):
             result_widget = self.add_child(CoactiveWidgetStub(view, 'main', []))
             result_widget.add_child(CoactiveWidgetStub(view, 'child', coactive_widgets))
             method_result = WidgetResult(result_widget, as_json_and_result=True)
-            remote_method = RemoteMethod(view, 'amethod', lambda: None, default_result=method_result)
+            remote_method = RemoteMethod(view, 'amethod', lambda: None, default_result=method_result, disable_csrf_check=True)
             view.add_resource(remote_method)
 
     wsgi_app = web_fixture.new_wsgi_app(child_factory=WidgetWithRemoteMethod.factory())
@@ -477,7 +510,8 @@ def test_coactive_widgets(web_fixture):
     browser.post('/_amethod_method', {})
     json_response = json.loads(browser.raw_html)
     assert json_response == {'success': True,
-                             'widgets': {
+                             'exception': '',
+                             'result': {
                                 'main': '<main><script type="text/javascript"></script>',
                                 'coactive1': '<coactive1><script type="text/javascript"></script>',
                                 'coactive2': '<coactive2><script type="text/javascript"></script>'}
