@@ -279,7 +279,8 @@ def test_non_writable_input_is_dealt_with_like_invalid_input(web_fixture):
     browser = Browser(wsgi_app)
     browser.open('/')
 
-    browser.post(fixture.form.event_channel.get_url().path, {'event.some_form-an_event?':'', 'some_form-field_name': 'illigitimate value', 'some_form-_reahl_database_concurrency_digest':''})
+    csrf_token = browser.get_value('//input[@name="some_form-_reahl_csrf_token"]')
+    browser.post(fixture.form.event_channel.get_url().path, {'event.some_form-an_event?':'', 'some_form-field_name': 'illigitimate value', 'some_form-_reahl_database_concurrency_digest':'', 'some_form-_reahl_csrf_token': csrf_token})
     browser.follow_response()
     assert model_object.field_name == 'Original value'
 
@@ -311,7 +312,8 @@ def test_non_writable_events_are_dealt_with_like_invalid_input(web_fixture):
     browser = Browser(wsgi_app)
     browser.open('/')
 
-    browser.post(fixture.form.event_channel.get_url().path, {'event.some_form-an_event?':'', 'some_form-_reahl_database_concurrency_digest':''})
+    csrf_token = browser.get_value('//input[@name="some_form-_reahl_csrf_token"]')
+    browser.post(fixture.form.event_channel.get_url().path, {'event.some_form-an_event?':'', 'some_form-_reahl_database_concurrency_digest':'', 'some_form-_reahl_csrf_token': csrf_token})
     browser.follow_response()
     error_label = browser.get_html_for('//label')
     input_id = browser.get_id_of('//input[@name="event.some_form-an_event?"]')
